@@ -3,7 +3,8 @@ use strict;
 use warnings;
 
 package Dancer2::Plugin::Deferred;
-$Dancer2::Plugin::Deferred::VERSION = '0.007015';
+our $AUTHORITY = 'cpan:YANICK';
+$Dancer2::Plugin::Deferred::VERSION = '0.007016';
 # ABSTRACT: Defer messages or data across redirections
 # VERSION
 
@@ -11,16 +12,16 @@ use Carp qw/croak/;
 use URI;
 use URI::QueryParam;
 
-use Dancer2::Plugin qw(:no_dsl);
+use Dancer2::Plugin;
 
 my $conf;
 
 register 'deferred' => sub {
-    my ( $dsl, $key, $value ) = plugin_args(@_);
+    my ( $dsl, $key, $value ) = @_;
     $conf ||= _get_conf();
     my $app = $dsl->app;
     my $context;
-    if ( $Dancer2::VERSION < 0.15 ) {
+    if ( $Dancer2::VERSION && $Dancer2::VERSION < 0.15 ) {
         $context = $app->context;
     }
 
@@ -30,7 +31,7 @@ register 'deferred' => sub {
     # another session
     my $data;
     
-    if ( $Dancer2::VERSION < 0.15 ) {
+    if ( $Dancer2::VERSION && $Dancer2::VERSION < 0.15 ) {
         $data = $app->session( $conf->{session_key_prefix} . $id ) || {};
     }
     else {
@@ -43,7 +44,7 @@ register 'deferred' => sub {
         $data->{$key} = $value;
     }
     else {
-        if ( $Dancer2::VERSION < 0.15 ) {
+        if ( $Dancer2::VERSION && $Dancer2::VERSION < 0.15 ) {
             $value = $context->var( $conf->{var_keep_key} ) ? $data->{$key} : delete $data->{$key};
         }
         else {
@@ -53,7 +54,7 @@ register 'deferred' => sub {
     }
 
     # store remaining data or clear it if no deferred messages are left
-    if ( $Dancer2::VERSION < 0.15 ) {
+    if ( $Dancer2::VERSION && $Dancer2::VERSION < 0.15 ) {
         if ( keys %$data ) {
             $app->session( $conf->{session_key_prefix} . $id => $data );
             $context->var( $conf->{var_key} => $id );
@@ -82,19 +83,19 @@ sub _get_all_deferred {
     my $dsl = shift;
     my $app = $dsl->app;
     my $context;
-    if ( $Dancer2::VERSION < 0.15 ) {
+    if ( $Dancer2::VERSION && $Dancer2::VERSION < 0.15 ) {
         $context = $app->context;
     }
 
     my $id = _get_id($dsl);
     my $data;
-    if ( $Dancer2::VERSION < 0.15 ) {
+    if ( $Dancer2::VERSION && $Dancer2::VERSION < 0.15 ) {
         $data = $app->session( $conf->{session_key_prefix} . $id ) || {};
     }
     else {
         $data = $dsl->session( $conf->{session_key_prefix} . $id ) || {};
     }
-    if ( $Dancer2::VERSION < 0.15 ) {
+    if ( $Dancer2::VERSION && $Dancer2::VERSION < 0.15 ) {
     
         unless ( $context->var( $conf->{var_keep_key} ) ) {
             $app->session->delete( $conf->{session_key_prefix} . $id );
@@ -116,7 +117,7 @@ sub _get_deferred_param {
     my $dsl = shift;
     $conf ||= _get_conf();
 
-    if ( $Dancer2::VERSION < 0.15 ) {
+    if ( $Dancer2::VERSION && $Dancer2::VERSION < 0.15 ) {
         $dsl->app->context->var( $conf->{var_keep_key} => 1 );
         return ( $conf->{params_key} => $dsl->app->context->var( $conf->{var_key} ) );
 
@@ -132,7 +133,7 @@ sub _get_id {
     my $dsl = shift;
     $conf ||= _get_conf();
 
-    if ( $Dancer2::VERSION < 0.15 ) {
+    if ( $Dancer2::VERSION && $Dancer2::VERSION < 0.15 ) {
         return $dsl->app->context->var( $conf->{var_key} )
             || sprintf( "%08d", int( rand(100_000_000) ) );
     }
@@ -175,7 +176,7 @@ on_plugin_import {
                 $conf ||= _get_conf();
                 my $id;
                
-                if ( $Dancer2::VERSION < 0.15 ) {
+                if ( $Dancer2::VERSION && $Dancer2::VERSION < 0.15 ) {
                     $id = $dsl->context->request->params->{$conf->{params_key}};
                     $dsl->app->context->var( $conf->{var_key} => $id )
                     if $id;
@@ -196,7 +197,7 @@ on_plugin_import {
             code => sub {
                 my $response = shift;
                 $conf ||= _get_conf();
-                if ( $Dancer2::VERSION < 0.15 ) {
+                if ( $Dancer2::VERSION && $Dancer2::VERSION < 0.15 ) {
                     if ( $dsl->app->context->var( $conf->{var_key} ) && $response->status =~ /^3/ ) {
                         my $u = URI->new( $response->header("Location") );
                         $u->query_param( _get_deferred_param($dsl) );
@@ -235,7 +236,7 @@ Dancer2::Plugin::Deferred - Defer messages or data across redirections
 
 =head1 VERSION
 
-version 0.007015
+version 0.007016
 
 =head1 SYNOPSIS
 
@@ -327,10 +328,24 @@ variable to true to ensure the message remains to be retrieved by the link.
 Thank you to mst for explaining why L<Catalyst::Plugin::StatusMessages> does
 what it does and putting up with my dumb ideas along the way.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 David Golden <dagolden@cpan.org>
 
+=item *
+
+Yanick Champoux <yanick@cpan.org>
+
+=item *
+
+Deluxaran <deluxaran@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2012 by David Golden.
